@@ -49,7 +49,7 @@ ResamplingBootstrap = R6Class("ResamplingBootstrap", inherit = Resampling,
         ratio   = p_dbl(0, upper = 1, tags = "required"),
         repeats = p_int(1L, tags = "required")
       )
-      ps$values = list(ratio = 1, repeats = 30L)
+      ps$set_values(ratio = 1, repeats = 30L)
 
       super$initialize(id = "bootstrap", param_set = ps, duplicated_ids = TRUE,
         label = "Bootstrap", man = "mlr3::mlr_resamplings_bootstrap")
