@@ -5,7 +5,7 @@
 #' This is a S3 generic. mlr3 ships with methods for the following objects:
 #'
 #' 1. [TaskClassif]: returns the object as-is, possibly cloned.
-#' 2. [`formula`], [data.frame()], [matrix()], [Matrix::Matrix()] and [DataBackend]: provides an alternative to the constructor of [TaskClassif].
+#' 2. [`formula`], [data.frame()], [matrix()], and [DataBackend]: provides an alternative to the constructor of [TaskClassif].
 #' 3. [TaskRegr]: Calls [convert_task()].
 #'
 #' Note that the target column will be converted to a `factor()`, if possible.
@@ -35,7 +35,7 @@ as_task_classif.TaskClassif = function(x, clone = FALSE, ...) { # nolint
 #'   Level of the positive class. See [TaskClassif].
 #' @template param_label
 #' @export
-as_task_classif.data.frame = function(x, target = NULL, id = deparse1(substitute(x)), positive = NULL, label = NA_character_, ...) { # nolint
+as_task_classif.data.frame = function(x, target, id = deparse1(substitute(x)), positive = NULL, label = NA_character_, ...) { # nolint
   force(id)
 
   assert_data_frame(x, min.rows = 1L, min.cols = 1L, col.names = "unique")
@@ -67,29 +67,7 @@ as_task_classif.matrix = function(x, target, id = deparse1(substitute(x)), label
 
 #' @rdname as_task_classif
 #' @export
-as_task_classif.Matrix = function(x, target, id = deparse1(substitute(x)), label = NA_character_, ...) { # nolint
-  force(id)
-
-  assert_names(colnames(x), "unique")
-  assert_choice(target, colnames(x))
-
-  ii = which(target == colnames(x))
-  dense = data.table(..row_id = seq_len(nrow(x)))
-  y = x[, target, drop = TRUE]
-
-  if (!is.factor(y)) {
-    # move target col from matrix to data frame for conversion
-    set(dense, j = target, value = factor(x[, ii, drop = TRUE]))
-    x = x[, -ii, drop = FALSE]
-  }
-
-  b = DataBackendMatrix$new(x, dense = dense, primary_key = "..row_id")
-  as_task_classif(b, target = target, id = id, label = label, ...)
-}
-
-#' @rdname as_task_classif
-#' @export
-as_task_classif.DataBackend = function(x, target = NULL, id = deparse1(substitute(x)), positive = NULL, label = NA_character_, ...) { # nolint
+as_task_classif.DataBackend = function(x, target, id = deparse1(substitute(x)), positive = NULL, label = NA_character_, ...) { # nolint
   force(id)
 
   assert_choice(target, x$colnames)
@@ -100,7 +78,7 @@ as_task_classif.DataBackend = function(x, target = NULL, id = deparse1(substitut
 #' @rdname as_task_classif
 #' @inheritParams convert_task
 #' @export
-as_task_classif.TaskRegr = function(x, target = NULL, drop_original_target = FALSE, drop_levels = TRUE, ...) { # nolint
+as_task_classif.TaskRegr = function(x, target, drop_original_target = FALSE, drop_levels = TRUE, ...) { # nolint
   convert_task(intask = x, target = target, new_type = "classif", drop_original_target = FALSE, drop_levels = TRUE)
 }
 
