@@ -28,6 +28,10 @@ ee[["logical___POSIXct"]] =
   function(value, type, levels) {
     if (allMissing(value)) .POSIXct(value, tz = "") else value
   }
+ee[["logical___Date"]] =
+  function(value, type, levels) {
+    if (allMissing(value)) as.Date(value) else value
+  }
 
 ## from: integer
 ee[["integer___logical"]] =
@@ -44,6 +48,8 @@ ee[["integer___ordered"]] =
   ee[["logical___ordered"]]
 ee[["integer___POSIXct"]] =
   ee[["logical___POSIXct"]]
+ee[["integer___Date"]] =
+  ee[["logical___Date"]]
 
 ## from: numeric
 ee[["numeric___logical"]] =
@@ -60,6 +66,8 @@ ee[["numeric___ordered"]] =
   ee[["logical___ordered"]]
 ee[["numeric___POSIXct"]] =
   ee[["logical___POSIXct"]]
+ee[["numeric___Date"]] =
+  ee[["logical___Date"]]
 
 ## from: character
 ee[["character___logical"]] =
@@ -83,6 +91,11 @@ ee[["character___POSIXct"]] =
     x = try(as.POSIXct(value, ""), silent = TRUE)
     if (inherits(x, "try-error")) value else x
   }
+ee[["character___Date"]] =
+  function(value, type, levels) {
+    x = try(as.Date(value), silent = TRUE)
+    if (inherits(x, "try-error")) value else x
+  }
 
 ## from: factor
 ee[["factor___logical"]] =
@@ -99,6 +112,8 @@ ee[["factor___ordered"]] =
   }
 ee[["factor___POSIXct"]] =
   ee[["character___POSIXct"]]
+ee[["factor___Date"]] =
+  ee[["character___Date"]]
 
 ## from: ordered
 ee[["ordered___character"]] =
@@ -109,6 +124,20 @@ ee[["ordered___ordered"]] =
   ee[["ordered___ordered"]]
 ee[["ordered___POSIXct"]] =
   ee[["character___POSIXct"]]
+ee[["ordered___Date"]] =
+  ee[["character___Date"]]
+
+## from: POSIXct
+ee[["POSIXct___Date"]] =
+  function(value, type, levels) {
+    as.Date(value)
+  }
+
+## from: Date
+ee[["Date___POSIXct"]] =
+  function(value, type, levels) {
+    as.POSIXct(value)
+  }
 
 rm(ee)
 # nolint end
