@@ -6,6 +6,10 @@
 #' For large-scale benchmarking we recommend to use the \CRANpkg{mlr3batchmark} package.
 #' This package runs benchmark experiments on high-performance computing clusters and handles failed experiments.
 #'
+#' @section Stochasticity:
+#' Note that uninstantiated [`Resampling`]s are instantiated on the task, making
+#' the function stochastic even in case of deterministic learners.
+#'
 #' @param design ([data.frame()])\cr
 #'   Data frame (or [data.table::data.table()]) with three columns: "task", "learner", and "resampling".
 #'   Each row defines a resampling by providing a [Task], [Learner] and an instantiated [Resampling] strategy.
@@ -101,11 +105,11 @@ benchmark = function(design, store_models = FALSE, store_backends = TRUE, encaps
 
   # check for multiple task types
   task_types = unique(map_chr(design$task, "task_type"))
-  if (length(task_types) > 1) {
+  if (length(task_types) > 1L) {
     stopf("Multiple task types detected, but mixing types is not supported: %s", str_collapse(task_types))
   }
   learner_types = unique(map_chr(design$learner, "task_type"))
-  if (length(learner_types) > 1) {
+  if (length(learner_types) > 1L) {
     stopf("Multiple learner types detected, but mixing types is not supported: %s", str_collapse(learner_types))
   }
 
