@@ -13,12 +13,3 @@ fix_factor_levels.data.table = function(data, levels, ...) { # nolint
   }, data = data)
   data[]
 }
-
-#' @export
-fix_factor_levels.Matrix = function(data, levels, ...) { # nolint
-  levels = levels[intersect(names(levels), names(data))]
-  if (length(levels)) {
-    stopf("Factor handling in Matrix data is not supported")
-  }
-  data
-}
