@@ -623,8 +623,7 @@ test_that("validation task is cloned", {
 test_that("task is cloned when assining internal validation task", {
   task = tsk("iris")
   task$internal_valid_task = task
-  # TODO: re-enable after $weights has been removed
-  # expect_false(identical(task, task$internal_valid_task))
+  expect_false(identical(task, task$internal_valid_task))
 })
 
 test_that("validation task changes a task's hash", {
@@ -921,7 +920,7 @@ test_that("$data() is not called during task construction", {
     inherit = DataBackendDataTable,
     cloneable = FALSE,
     public = list(
-      data = function(rows, cols, data_format) {
+      data = function(rows, cols) {
         stop("Bug")
       }
     )
@@ -969,3 +968,55 @@ test_that("row_ids_backend works correctly", {
   task$filter(1:25)
   expect_set_equal(task$row_ids_backend, 1:768)
 })
+
+test_that("$levels with cols works (#1323)", {
+  task = TaskClassif$new(id = "example", target = "target", backend = data.table(
+    target = factor(c("S", "T", "U")),
+    x = ordered(c("A", "B", "C")),
+    y = factor(c("L", "M", "N"))
+  ))
+
+  expect_equal(task$levels(), list(target = c("S", "T", "U"), x = c("A", "B", "C"), y = c("L", "M", "N")))
+  expect_equal(task$levels(cols = c("y", "x")), list(y = c("L", "M", "N"), x = c("A", "B", "C")))
+})
+
+test_that("$materialize_view works", {
+  task = tsk("iris")
+  task$select(head(task$feature_names, 2))
+  task$materialize_view()
+
+  expect_backend(task$backend)
+  expect_task(task)
+  expect_set_equal(task$feature_names, c("Petal.Length", "Petal.Width"))
+  expect_set_equal(task$target_names, "Species")
+  expect_data_table(task$col_info, key = "id")
+  expect_set_equal(task$col_info$id, c(task$backend$primary_key, task$feature_names, task$target_names))
+
+  learner = lrn("classif.featureless")$train(task)
+  expect_set_equal(learner$model$features, c("Petal.Length", "Petal.Width"))
+})
+
+test_that("$materialize_view works with internal valid task", {
+  task = tsk("iris")
+  task$select(head(task$feature_names, 2))
+  task$filter(1:140)
+  task$internal_valid_task = 1:10
+  task$materialize_view(TRUE)
+
+  iv = task$internal_valid_task
+  expect_backend(iv$backend)
+  expect_task(iv)
+  expect_set_equal(iv$feature_names, c("Petal.Length", "Petal.Width"))
+  expect_set_equal(iv$target_names, "Species")
+  expect_data_table(iv$col_info, key = "id")
+  expect_set_equal(iv$col_info$id, c(task$backend$primary_key, task$feature_names, task$target_names))
+})
+
+test_that("materialize_view works with duplicates", {
+  task = tsk("iris")
+  task2 = task$clone(deep = TRUE)
+  task$filter(c(1, 1, 2))
+  task2$filter(c(1, 1, 2))
+  task2$materialize_view()
+  expect_equal(task$data(), task2$data())
+})
