@@ -14,10 +14,14 @@ test_that("as_learner conversion", {
 test_that("discard_state", {
   learner = lrn("classif.rpart")$train(tsk("iris"))
   learner2 = as_learner(learner, clone = TRUE, discard_state = TRUE)
-  expect_true(is.null(learner2$state))
+  expect_null(learner2$state)
   expect_false(is.null(learner$state))
 
   learner3 = lrn("classif.rpart")
   as_learner(learner3, clone = FALSE, discard_state = TRUE)
-  expect_true(is.null(learner3$state))
+  expect_null(learner3$state)
+})
+
+test_that("error when arguments are misspelled", {
+  expect_error(as_learner(lrn("classif.rpart"), clone2 = TRUE), "Received the following")
 })
