@@ -5,7 +5,7 @@ test_that("autotest", {
   expect_true(result, info = result$error)
 
   exclude = c("formula", "data", "weights", "subset", "na.action", "method", "model",
-    "x", "y", "parms", "control", "cost", "keep_model")
+    "x", "y", "parms", "control", "cost", "keep_model", "use_weights")
   result = run_paramtest(learner, list(rpart::rpart, rpart::rpart.control), exclude, tag = "train")
   expect_true(result, info = result$error)
 
@@ -36,21 +36,6 @@ test_that("selected_features", {
   expect_subset(sf, task$feature_names, empty.ok = FALSE)
 })
 
-test_that("weights", {
-  task = TaskRegr$new("foo", as_data_backend(cbind(iris, data.frame(w = rep(c(1, 10, 100), each = 50)))), target = "Sepal.Length")
-  task$set_col_roles("w", character())
-  learner = lrn("regr.rpart")
-
-  learner$train(task)
-  p1 = learner$predict(task)
-
-  task$set_col_roles("w", "weight")
-  learner$train(task)
-  p2 = learner$predict(task)
-
-  expect_lt(p1$score(), p2$score())
-})
-
 test_that("default_values on rpart", {
   learner = lrn("regr.rpart")
   search_space = ps(
@@ -63,3 +48,18 @@ test_that("default_values on rpart", {
   values = default_values(learner, search_space, task)
   expect_names(names(values), permutation.of = c("minsplit", "minbucket", "cp"))
 })
+
+test_that("use_weights actually influences the model", {
+  # Task with weights_learner role defined in helper_misc.R
+  task = cars_weights_learner
+  learner = lrn("regr.rpart", use_weights = "use")
+  learner$train(task)
+  p1 = learner$predict(task)
+
+  learner = lrn("regr.rpart", use_weights = "ignore")
+  learner$train(task)
+  p2 = learner$predict(task)
+
+  # Predictions should differ if weights were used
+  expect_false(all(p1$response == p2$response))
+})
