@@ -38,5 +38,5 @@ test_that("prediction does not drop dimension (#551)", {
 
   bmr = benchmark(design)
   expect_number(bmr$aggregate(msr("classif.ce"))[["classif.ce"]])
-  expect_equal(map(bmr$data$data$fact$prediction, names), list("test"))
+  expect_equal(map(get_private(bmr)$.data$data$fact$prediction, names), list("test"))
 })
