@@ -26,3 +26,9 @@ test_that("sugar functions", {
   expect_task_generator(tgen("xor"))
   expect_list(tgens(c("xor", "smiley")), "TaskGenerator")
 })
+
+test_that("as.data.table(..., objects = TRUE)", {
+  tab  = as.data.table(mlr_task_generators, objects = TRUE)
+  expect_data_table(tab)
+  expect_list(tab$object, "TaskGenerator", any.missing = FALSE)
+})
